/***
 * Creates an array with all falsey values removed.
 * The values `false`, `null`, `0`, `""`, `undefined`, and `NaN` are falsey.
 * @param array array to compact.
 * @returns {T[]} Returns the new array of filtered values.
 */
/***
 * Creates an array with all falsey values removed.
 * The values `false`, `null`, `0`, `""`, `undefined`, and `NaN` are falsey.
 * @param array array to compact.
 * @returns {T[]} Returns the new array of filtered values.
 */ export function compact(array) {
    return array.filter(function (i) { return i; });
}
/***
 * Creates a new array concatenating array with any additional arrays and/or values.
 * @param item item or array to concatenate
 * @returns {T[]} Returns the new concatenated array.
 */
export function concat() {
    var item = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        item[_i] = arguments[_i];
    }
    return (_a = []).concat.apply(_a, item);
    var _a;
}
/***
 * Flattens array a single level deep.
 * @param array The array to flatten.
 * @returns {T[]} Return Flattened array.
 */
export function flatten(array) {
    return [].concat.apply([], array);
}
/***
 * Creates a duplicate-free version of an array,
 * using `indexOf` for equality comparisons,
 * in which only the first occurrence of each element is kept.
 * The order of result values is determined by the order they occur in the array.
 * @param array The array to inspect.
 * @returns {T[]} Duplicate free array
 */
export function uniq(array) {
    return array.filter(function (item, index, array) { return array.indexOf(item) === index; });
}
/***
 * Creates an array excluding all given values using `indexOf` for equality comparisons.
 * @param array The array to inspect.
 * @param remove The array to exclude.
 * @returns {T[]} Returns the new array of filtered values.
 */
export function without(array, remove) {
    return array.filter(function (item) { return !contains(remove, item); });
}
/***
 * Check if item is in array using `indexOf`
 * @param array The array to inspect
 * @param item The item to check
 * @returns {boolean} Return `true` if item is in array
 */
export function contains(array, item) {
    return array.indexOf(item) !== -1;
}
/***
 * Creates an symmetric difference array of values not included in the other given arrays.
 * The order and references of result values are determined by the first array.
 * @param array1 The first array
 * @param array2 The second array
 * @returns {[T]} Returns values not included in the other given arrays.
 */
export function difference(array1, array2) {
    return without(array1, array2).concat(without(array2, array1));
}
/***
 * Creates an array of values. If value from `toToggle` found in `existing` it gets removed,
 * otherwise it's added.
 * The order and references of result values are determined by the first array.
 * @param existing Existing elements array
 * @param toToggle Array of elements to toggle
 * @returns {[T]} Returns new array of toggled values
 */
export function toggle(existing, toToggle) {
    return without(existing, toToggle).concat(without(toToggle, existing));
}
//# sourceMappingURL=arrays.js.map