import { compact, concat, contains, difference, flatten, toggle, uniq, without } from './arrays';
import { curry, debounce, delayed, identity, memoize, noop, once } from './functions';
import { filter, isEmpty, keys, mapKeys, mapKeyValues, mapValues, merge, omit, patch, pick, reduce, shallowEqual, values } from './objects';
import { camelCase, capitalize, kebabCase, lowerCase, snakeCase, template, trim, wildcardToRegExp, words } from './strings';
export declare type CurriedFunction1<T1, R> = (v1: T1) => R;
export interface CurriedFunction2<T1, T2, R> {
    (v1: T1): (v2: T2) => R;
    (v1: T1, v2: T2): R;
}
export interface CurriedFunction3<T1, T2, T3, R> {
    (v1: T1): CurriedFunction2<T2, T3, R>;
    (v1: T1, v2: T2): (v3: T3) => R;
    (v1: T1, v2: T2, v3: T3): R;
}
export { curry, noop, identity, delayed, debounce, memoize, once, template, trim, capitalize, snakeCase, kebabCase, camelCase, lowerCase, words, wildcardToRegExp, compact, concat, contains, toggle, without, difference, flatten, uniq, shallowEqual, patch, filter, reduce, mapValues, mapKeyValues, mapKeys, merge, pick, omit, isEmpty, keys, values };
declare const _default: {
    curry: {
        <T1, TResult>(fn: (a: T1) => TResult, n?: number | undefined): CurriedFunction1<T1, TResult>;
        <T1, T2, TResult>(fn: (a: T1, b: T2) => TResult, n?: number | undefined): CurriedFunction2<T1, T2, TResult>;
        <T1, T2, T3, TResult>(fn: (a: T1, b: T2, c: T3) => TResult, n?: number | undefined): CurriedFunction3<T1, T2, T3, TResult>;
    };
    noop: () => void;
    identity: <T>(i: T) => T;
    delayed: <T extends Function>(this: any, schedulerFn: (fn: Function) => void, fn: T) => T;
    debounce: <T extends Function>(func: T, wait: number, immediate?: boolean) => T;
    memoize: <T extends Function>(this: any, func: T) => T;
    once: <T extends Function>(func: T) => T;
    template: (template: string) => (data: object) => string;
    trim: (str: string) => string;
    capitalize: (str: string) => string;
    snakeCase: (v2: string) => string;
    kebabCase: (v2: string) => string;
    camelCase: (str: string) => string;
    lowerCase: (s: string) => string;
    words: (str?: string | undefined) => string[];
    wildcardToRegExp: (wildcardPattern: string, flags?: string | undefined) => RegExp;
    compact: <T>(array: T[]) => T[];
    concat: <T>(...item: (T | T[])[]) => T[];
    contains: <T>(array: T[], item: T) => boolean;
    toggle: <T>(existing: T[], toToggle: T[]) => T[];
    without: <T>(array: T[], remove: T[]) => T[];
    difference: <T>(array1: T[], array2: T[]) => T[];
    flatten: <T>(array: (T | T[])[]) => T[];
    uniq: <T>(array: T[]) => T[];
    shallowEqual: (objA: Object, objB: Object) => boolean;
    patch: <T extends object>(old: T, patch: Partial<T>) => Partial<T>;
    filter: <T extends object>(item: T, filterFn: (key: keyof T) => boolean) => Partial<T>;
    reduce: <V, T extends {
        [key: string]: V;
    }, R>(item: T, reduceFn: (key: keyof T, value: V) => R) => {
        [key: string]: R;
    };
    mapValues: <V, T extends {
        [key: string]: V;
    }, R>(item: T, mapValueFn: <R>(value: V) => R) => {
        [key: string]: R;
    };
    mapKeyValues: <V, T extends {
        [key: string]: V;
    }, R>(item: T, mapKeyFn: (key: keyof T) => string, mapValueFn: (value: V) => R) => {
        [key: string]: R;
    };
    mapKeys: <V, T extends {
        [key: string]: V;
    }>(item: T, mapKeyFn: (key: keyof T) => string) => {
        [key: string]: V;
    };
    merge: <T, S>(target: T, source: S) => (T & S) | (T | S)[];
    pick: <T extends object>(item: T, keys: (string | keyof T)[]) => Partial<T>;
    omit: <T extends object>(item: T, keys: (string | keyof T)[]) => Partial<T>;
    isEmpty: (item?: Object | any[] | undefined) => boolean;
    keys: <T extends object>(item: T) => keyof T[];
    values: <V, T extends {
        [key: string]: V;
    }>(item: T) => V[];
};
export default _default;
